@@ -7,9 +7,10 @@
  */
 
 #include <cstdlib>
-#include <iostream>
 #include <gtkmm.h>
 
+using std::strtod;
+
 class CellItem_Product
 {
 public:
@@ -26,7 +27,7 @@ class Example_TreeView_EditableCells : public Gtk::Window
 {
 public:
   Example_TreeView_EditableCells();
-  ~Example_TreeView_EditableCells() override;
+  virtual ~Example_TreeView_EditableCells();
 
 protected:
   //signal handlers:
@@ -203,16 +204,8 @@ void Example_TreeView_EditableCells::on_column_number_edited(const Glib::ustring
     if(iter)
     {
       //Convert the text to a number, using the same logic used by GtkCellRendererText when it stores numbers.
-      int new_value = 0;
-      try
-      {
-        new_value = std::stoi(new_text);
-      }
-      catch (const std::exception& err)
-      {
-        std::cout << "Could not convert \"" << new_text << "\" to an integer. ("
-          << err.what() << ")" << std::endl;
-      }
+      char* pchEnd = nullptr;
+      int new_value = (int) strtod(new_text.c_str(), &pchEnd);
 
       //Store the user's new text in the model:
       Gtk::TreeRow row = *iter;
@@ -250,7 +243,7 @@ void Example_TreeView_EditableCells::add_columns()
 
   //And this is the way that works with the IRIX MipsPro compiler too:
   {
-    Gtk::TreeView::Column* pViewColumn = Gtk::make_managed<Gtk::TreeView::Column>("Number", m_columns.number);
+    Gtk::TreeView::Column* pViewColumn = Gtk::manage(new Gtk::TreeView::Column("Number", m_columns.number));
 
     //connect signal handlers for auto-storing of edited cell data
     Gtk::CellRenderer* pCellRenderer = pViewColumn->get_first_cell();
@@ -268,7 +261,7 @@ void Example_TreeView_EditableCells::add_columns()
   }
 
   {
-    Gtk::TreeView::Column* pViewColumn = Gtk::make_managed<Gtk::TreeView::Column>("Product", m_columns.product);
+    Gtk::TreeView::Column* pViewColumn = Gtk::manage(new Gtk::TreeView::Column("Product", m_columns.product));
 
     //connect signal handlers for auto-storing of edited cell data
     Gtk::CellRenderer* pCellRenderer = pViewColumn->get_first_cell();
